Options for search control.
Customized searchOptions for Feature Search
searchOptions(
url = NULL,
sourceData = NULL,
jsonpParam = NULL,
propertyLoc = NULL,
propertyName = NULL,
formatData = NULL,
filterData = NULL,
filtersearch = NULL,
moveToLocation = TRUE,
zoom = 17,
buildTip = NULL,
container = "",
minLength = 1,
initial = TRUE,
casesensitive = FALSE,
autoType = TRUE,
delayType = 400,
tooltipLimit = -1,
tipAutoSubmit = TRUE,
firstTipSubmit = FALSE,
autoResize = TRUE,
collapsed = TRUE,
autoCollapse = FALSE,
autoCollapseTime = 1200,
textErr = "Location Not Found",
textCancel = "Cancel",
textPlaceholder = "Search...",
position = "topleft",
hideMarkerOnCollapse = FALSE,
marker = list(icon = NULL, animate = TRUE, circle = list(radius = 10, weight = 3, color
= "#e03", stroke = TRUE, fill = FALSE))
)searchFeaturesOptions(
propertyName = "label",
initial = FALSE,
openPopup = FALSE,
...
)
url for search by ajax request, ex: `search.php?q={s}`. Can be function that returns string for dynamic parameter setting.
function that fill _recordsCache, passed searching text by first param and callback in second.
jsonp param name for search by jsonp service, ex: "callback".
field for remapping location, using array: ["latname","lonname"] for select double fields(ex. ["lat","lon"] ) support dotted format: "prop.subprop.title".
property in marker.options(or feature.properties for vector layer) trough filter elements in layer,.
callback for reformat all data from source to indexed data object.
callback for filtering data from text searched, params: textSearch, allRecords.
Optional comma-separated string to prepend to the search text
whether to move to the found location
zoom to this level when moving to location
function that return row tip html node(or html string), receive text tooltip in first param.
container id to insert Search Control
minimal text length for autocomplete
search elements only by initial text
search elements in case sensitive text
complete input with first suggested result and select this filled-in text
delay while typing for show tooltip.
limit max results to show in tooltip. -1 for no limit
auto map panTo when click on tooltip
auto select first result con enter click
autoresize on input change
collapse search control at startup
collapse search control after submit(on button or on tips if enabled tipAutoSubmit).
delay for autoclosing alert and collapse after blur.
Error message
title in cancel button
placeholder value
position of the search input. Default is "topleft".
remove circle and marker on search control collapsed.
Let's you set the icon. Can be an icon made by makeIcon or makeAwesomeIcon
whether to open the popup associated with the feature when the feature is searched for
Other options to pass to searchOptions() function.